"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.getCjsConfiguration = getCjsConfiguration;
exports.getEsmConfiguration = getEsmConfiguration;
exports.getNodeConfiguration = getNodeConfiguration;
var _resolve = require("@essex/babel-config/resolve");
var _fs = require("fs");
var _path = require("path");
var _createBabelConfigJs = _interopRequireWildcard(require("./createBabelConfig.js"));
Object.keys(_createBabelConfigJs).forEach(function(key) {
    if (key === "default" || key === "__esModule") return;
    if (key in exports && exports[key] === _createBabelConfigJs[key]) return;
    Object.defineProperty(exports, key, {
        enumerable: true,
        get: function() {
            return _createBabelConfigJs[key];
        }
    });
});
var _getBrowsersListJs = require("./getBrowsersList.js");
function _interopRequireWildcard(obj) {
    if (obj && obj.__esModule) {
        return obj;
    } else {
        var newObj = {};
        if (obj != null) {
            for(var key in obj){
                if (Object.prototype.hasOwnProperty.call(obj, key)) {
                    var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {};
                    if (desc.get || desc.set) {
                        Object.defineProperty(newObj, key, desc);
                    } else {
                        newObj[key] = obj[key];
                    }
                }
            }
        }
        newObj.default = obj;
        return newObj;
    }
}
const cwd = process.cwd();
const packageJsonPath = (0, _path).join(cwd, 'package.json');
const packageJson = (0, _fs).existsSync('package.json') ? (0, _resolve).loadJson(packageJsonPath) : {};
const babelEsmOverride = (0, _path).join(cwd, 'babel.esm.js');
const babelCjsOverride = (0, _path).join(cwd, 'babel.cjs.js');
const useBuiltIns = packageJson.useBuiltIns || 'usage';
const corejs = packageJson.corejs || (useBuiltIns ? {
    version: 3,
    proposals: false
} : undefined);
function getCjsConfiguration(env, spec = {}) {
    // ALlows users to override default cjs emission
    // during build by defining 'babel.cjs.js'
    if ((0, _fs).existsSync(babelCjsOverride)) {
        return (0, _resolve).loadJson(babelCjsOverride);
    }
    return (0, _createBabelConfigJs).createBabelConfig({
        modules: 'cjs',
        targets: (0, _getBrowsersListJs).getBrowsersList(env, packageJson === null || packageJson === void 0 ? void 0 : packageJson.browserslist),
        useBuiltIns,
        corejs,
        ...spec
    });
}
function getEsmConfiguration(env, spec = {}) {
    // ALlows users to override default esm emission
    // during build by defining 'babel.esm.js'
    if ((0, _fs).existsSync(babelEsmOverride)) {
        return (0, _resolve).loadJson(babelEsmOverride);
    }
    return (0, _createBabelConfigJs).createBabelConfig({
        modules: 'esm',
        targets: (0, _getBrowsersListJs).getBrowsersList(env, packageJson.browserslist),
        useBuiltIns,
        corejs,
        ...spec
    });
}
function getNodeConfiguration(spec = {}) {
    return (0, _createBabelConfigJs).createBabelConfig({
        modules: 'cjs',
        targets: {
            node: 'current'
        },
        presets: [
            require('@babel/preset-typescript'),
            require('@babel/preset-react'), 
        ],
        ...spec
    });
}
